PhylomeDB3 Connector — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- next |
- previous |
- ETE documentation »
- ETE’s Reference Guide »

# PhylomeDB3 Connector

class `PhylomeDB3Connector`(host='84.88.66.245', db='phylomedb_3', user='public', passwd='public', port=3306)

  Returns a connector to a phylomeDB3 database.

  > db: database name in the host server. host: hostname in which phylomeDB is hosted. user: username to the database. port: port used to connect database. passwd: password to connect database.

  > An object whose methods can be used to query the database.

  `count_algs`(phylome_id)

    Returns how many alignments are for a given phylome

  `count_trees`(phylome_id)

    Retuns the frequency of each evolutionary method in the input phylome

  `get_algs`(id, phylome_id, raw_alg=True, clean_alg=True)

    Return the either the clean, the raw or both alignments for the input phylomeDB ID in the input phylome

  `get_all_isoforms`(id)

    Returns all the isoforms registered for the input phylomeDB ID

  `get_available_trees_by_phylome`(id, collateral=True)

    Returns information about which methods have been used to reconstruct every tree for a given phylomeDB ID grouped by phylome

  `get_best_tree`(id, phylome_id)

    return a tree for input id in the given phylome for the best fitting evolutionary model in terms of LK

  `get_clean_alg`(id, phylome_id)

    Return the raw alignment for the input phylomeDB ID in the given phylome

  `get_collateral_seeds`(protid)

    Return the trees where the protid is presented as part of the homolog sequences to the seed protein

  `get_external_ids`(ids)

    Returns all the external IDs registered in the ‘external_id’ table that are associated to the input phylomeDB IDs

  `get_genome_ids`(taxid, version, filter_isoforms=True)

    Returns the phylomeDB IDs for a given genome in the database filtering out, or not, the different isoforms for each ID

  `get_genome_info`(genome)

    Returns all available information about a registered genome/proteome

  `get_genomes`()

    Returns all current available genomes/proteomes

  `get_genomes_by_species`(taxid)

    Return all the proteomes/genomes registered for the input taxaid code

  `get_go_ids`(ids)

    Returns all available GO Terms associated to the input phylomeDB IDs

  `get_id_by_external`(external)

    Returns the protein id associated to a given external id

  `get_id_translations`(id)

    Returns all the registered translations of a given phylomeDB ID

  `get_info_homologous_seqs`(protid, phylome_id, tree=None, tree_method=False, sequence=False)

    Return all the available information for a given set of homologous sequences extracted from a tree from a given phylome.

  `get_longest_isoform`(id)

    Returns the longest isoform for a given phylomeDB ID

  `get_new_phylomedb_id`(old_id)

    Return the conversion between an old phylomeDB ID and a new one

  `get_old_phylomedb_ids`(ids)

    Returns all old phylomeDB IDs associated to each of the input phylomeDB IDs

  `get_phylome_algs`(phylome_id)

    Returns all alignments available for a given phylome

  `get_phylome_info`(phylome_id)

    Returns available information on a given phylome

  `get_phylome_seed_ids`(phylome_id, filter_isoforms=True)

    Returns the seed phylomeDB IDs for a given phylome being possible to filter out the longest isoforms

  `get_phylome_seed_ids_info`(phylome_id, start=0, offset=None, filter_isoforms=False)
  `get_phylome_trees`(phylome_id)

    Returns all trees available for a given phylome

  `get_phylomes`()

    Returns all current available phylomes

  `get_phylomes_for_seed_ids`(ids)

    Given a list of phylomeDB IDs, return in which phylomes these IDs have been used as a seed

  `get_prot_gene_names`(ids)

    Returns all possible protein and gene names associated to the input phylomeDB IDs

  `get_proteomes_in_phylome`(phylome_id)

    Returns a list of proteomes associated to a given phylome_id

  `get_raw_alg`(id, phylome_id)

    Return the raw alignment for the input phylomeDB ID in the given phylome

  `get_seq_info_in_tree`(id, phylome_id, method=None)

    Return all the available information for each sequence from tree/s asociated to a tuple (protein, phylome) identifiers.

  `get_seq_info_msf`(id, phylome_id)

    Return all available information for the homologous sequences to the input phylomeDB ID in the input phylome using the best tree to compute the set of homologous sequences

  `get_seqid_info`(id)

    Returns available information about a given protid

  `get_seqs_in_genome`(taxid, version, filter_isoforms=True)

    Returns all sequences of a given proteome, filtering the

  `get_species`()

    Returns all current registered species in the database

  `get_species_in_phylome`(phylome_id)

    Returns a list of proteomes associated to a given phylome_id

  `get_species_info`(taxid=None, code=None)

    Returns all information on a given species/code

  `get_tree`(id, phylome_id, method=None, best_tree=False)

    Depending in the input parameters select either .- a tree with the best evolutionary model in terms of LK (best_tree) .- a tree reconstructed using a specific model (method) .- all available model/trees for the tuple (phylomeDB ID, phylome ID)

  `search_id`(id)

    Returns a list of the longest isoforms for each proteome where the ID is already registered. The ID can be a current phylomeDB ID version, former phylomeDB ID or an external ID.

### Navigation

- index
- modules |
- next |
- previous |
- ETE documentation »
- ETE’s Reference Guide »